@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _MOUSEDRV_H
-#define _MOUSEDRV_H
+#ifndef VICE_MOUSEDRV_H
+#define VICE_MOUSEDRV_H
 
 #include "types.h"
 
@@ -46,4 +46,3 @@ extern void mouse_set_cooperative_level(void);
 extern int _mouse_x, _mouse_y;
 
 #endif
-
